@@ -8,6 +8,9 @@ Coming soon:
  - Simulated Treatment Comparison (STC)
 """
 
-__version__ = "0.1.1"
+from pdoc import __pdoc__
+
+__pdoc__["_maic"] = True
+__version__ = "0.2.0"
 
 from ._maic import MAIC
